/*
 * TCS Alignment Toolbox
 * 
 * Copyright (C) 2013, 2014
 * Benjamin Paaßen, Charlie Krüger, Georg Zentgraf
 * AG Theoretical Computer Science
 * Centre of Excellence Cognitive Interaction Technology (CITEC)
 * University of Bielefeld
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 * 
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package de.unibi.citec.tcs.alignment;

import de.unibi.citec.tcs.alignment.sequence.Sequence;

/**
 * This is an implementation of the AbstractStrictDTWAlgorithm to
 * calculate just the score.
 *
 * @author Benjamin Paassen - bpaassen@techfak.uni-bielefeld.de
 */
public class StrictDTWScoreAlgorithm extends AbstractStrictDTWAlgorithm<Double> {

	public StrictDTWScoreAlgorithm(final AlignmentSpecification spec) {
		super(Double.class, spec);
	}

	/**
	 * {@inheritDoc }
	 */
	@Override
	public Double transformToResult(double[][] dtwMatrix, Sequence a, Sequence b) {
		final double normalization = a.getNodes().size() + b.getNodes().size();
		return dtwMatrix[a.getNodes().size() - 1][b.getNodes().size() - 1] / normalization;
	}

}
