/* 
 * TCS Alignment Toolbox
 * 
 * Copyright (C) 2013, 2014
 * Benjamin Paaßen, Charlie Krüger, Georg Zentgraf
 * AG Theoretical Computer Science
 * Centre of Excellence Cognitive Interaction Technology (CITEC)
 * University of Bielefeld
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 * 
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package de.unibi.citec.tcs.alignment.comparators;

import de.unibi.citec.tcs.alignment.sequence.Value;
import de.unibi.citec.tcs.alignment.sequence.ValueType;

/**
 * This defines a function that returns a normalized distance between two
 * objects.
 *
 * @author Benjamin Paassen - bpaassen@techfak.uni-bielefeld.de
 * @param <X> the value this comparator is fit for.
 */
public interface Comparator<X extends Value> {

    /**
     *
     * @return The type this comparator can compare.
     */
    public ValueType getType();

    /**
     * This has to return a distance between a and b with the following
     * restrictions:
     * <ul><li>The return value has to lie between 0 and 1.</li>
     * <li>1 means maximum dissimilarity between a and b.</li>
     * <li>0 means maximum similarity between a and b (especially it should be
     * true that a = b implies a zero distance).</li>
     * <li>distance(a,b) should be equal or at least close to
     * distance(b,a)</li></ul>
     *
     * Please note that this has to be well-defined, even if an input is null.
     *
     * @param a the left input.
     * @param b the right input.
     *
     * @return a distance between a and b.
     */
    public double compare(X a, X b);
}
