/* 
 * TCS Alignment Toolbox
 * 
 * Copyright (C) 2013, 2014
 * Benjamin Paaßen, Charlie Krüger, Georg Zentgraf
 * AG Theoretical Computer Science
 * Centre of Excellence Cognitive Interaction Technology (CITEC)
 * University of Bielefeld
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 * 
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package de.unibi.citec.tcs.alignment.comparators;

/**
 * This normalizes by using the function 1 - 1/(d+1).
 *
 * @author Benjamin Paassen - bpaassen@techfak.uni-bielefeld.de
 */
public class HyperbolicNormalizer implements Normalizer {

    private double alpha = 1;

    public HyperbolicNormalizer() {
    }

    /**
     *
     * @param alpha the slope of the hyperbola.
     */
    public void setAlpha(double alpha) {
        this.alpha = alpha;
    }

    /**
     *
     * @return the slope of the hyperbola.
     */
    public double getAlpha() {
        return alpha;
    }

    /**
     * {@inheritDoc }
     */
    @Override
    public double normalize(double distance) {
        return 1 - 1 / (alpha * distance + 1);
    }

    /**
     * {@inheritDoc }
     */
    @Override
    public int hashCode() {
        int hash = 3;
        hash
                = 41 * hash
                + (int) (Double.doubleToLongBits(this.alpha)
                ^ (Double.doubleToLongBits(this.alpha) >>> 32));
        return hash;
    }

    /**
     * {@inheritDoc }
     */
    @Override
    public boolean equals(Object obj) {
        if (obj == null) {
            return false;
        }
        if (getClass() != obj.getClass()) {
            return false;
        }
        final HyperbolicNormalizer other = (HyperbolicNormalizer) obj;
        if (Double.doubleToLongBits(this.alpha) != Double.doubleToLongBits(other.alpha)) {
            return false;
        }
        return true;
    }
}
