/* 
 * TCS Alignment Toolbox
 * 
 * Copyright (C) 2013, 2014
 * Benjamin Paaßen, Charlie Krüger, Georg Zentgraf
 * AG Theoretical Computer Science
 * Centre of Excellence Cognitive Interaction Technology (CITEC)
 * University of Bielefeld
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 * 
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package de.unibi.citec.tcs.alignment.sequence;

/**
 * This value is supposed to represent strings that are not restricted to a
 * certain alphabet. If you want to limit the number of possible values, please
 * refer to the SymbolValue class.
 *
 * @author Benjamin Paassen - bpaassen@techfak.uni-bielefeld.de
 */
public class StringValue extends AbstractValue {

    private String string;

    public StringValue() {
        super(ValueType.STRING);
    }

    public StringValue(String string) {
        super(ValueType.STRING);
        this.string = string;
    }

    /**
     * Returns the actual string.
     *
     * @return the actual string.
     */
    public String getString() {
        return string;
    }

    /**
     *
     * @param string the actual string.
     */
    public void setString(String string) {
        this.string = string;
    }

    /**
     * {@inheritDoc }
     */
    @Override
    public String toString() {
        return string;
    }

    /**
     * {@inheritDoc }
     */
    @Override
    public int hashCode() {
        int hash = 7;
        hash = 47 * hash + (this.string != null ? this.string.hashCode() : 0);
        return hash;
    }

    /**
     * {@inheritDoc }
     */
    @Override
    public boolean equals(Object obj) {
        if (obj == null) {
            return false;
        }
        if (getClass() != obj.getClass()) {
            return false;
        }
        final StringValue other = (StringValue) obj;
        if ((this.string == null) ? (other.string != null) : !this.string.equals(other.string)) {
            return false;
        }
        return true;
    }
}
