/* 
 * TCS Alignment Toolbox
 * 
 * Copyright (C) 2013, 2014
 * Benjamin Paaßen, Charlie Krüger, Georg Zentgraf
 * AG Theoretical Computer Science
 * Centre of Excellence Cognitive Interaction Technology (CITEC)
 * University of Bielefeld
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 * 
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package de.unibi.citec.tcs.alignment;

import de.unibi.citec.tcs.alignment.comparators.ReplacementCosts;
import de.unibi.citec.tcs.alignment.sequence.Sequence;
import junit.framework.TestCase;

/**
 *
 * @author Benjamin Paassen - bpaassen(at)techfak.uni-bielefeld.de
 */
public class StrictAllOptimalAlgorithmTest extends TestCase {

	public StrictAllOptimalAlgorithmTest(String testName) {
		super(testName);
	}

	@Override
	protected void setUp() throws Exception {
		super.setUp();
	}

	@Override
	protected void tearDown() throws Exception {
		super.tearDown();
	}

    /**
     * Test of calculateAlignment method, of class StrictAllOptimalAlgorithm.
     */
    public void testCalculateAlignment() {
        /*
         * we set up a very ambigous input: we align aaaa and aaa. You are free to choose where
         * you delete.
         */
        final Sequence a = new Sequence("aaaa");
        final Sequence b = new Sequence("aaa");
        final StrictAllOptimalAlgorithm instance = new StrictAllOptimalAlgorithm(
                new AlignmentSpecification(a));
        PathList pathList = instance.calculateAlignment(a, b);
        final double expectedScore = ReplacementCosts.GAPDEFAULT / 7;
        assertEquals(4, pathList.size());

        for (int p = 0; p < pathList.size(); p++) {
            final AlignmentPath path = pathList.get(p);
            assertEquals(expectedScore, path.getScore());
            //there should be one path for every possible place where we can delete.
            for (int o = 0; o < path.getOperations().size(); o++) {
                final OperationType type = path.getOperations().get(o).getType();
                if (o != p) {
                    assertEquals(OperationType.REPLACEMENT, type);
                } else {
                    assertEquals(OperationType.DELETION, type);
                }
            }
        }

        /* 
         * now we do that again, but we set the path limit to 3, so we only take 3 of the four
         * possible paths.
         */
        final int limit = pathList.size() - 1;
        instance.setPathLimit(limit);
        pathList = instance.calculateAlignment(a, b);
        assertEquals(limit, pathList.size());
        boolean[] variations = new boolean[4];
        for (int p = 0; p < limit; p++) {
            final AlignmentPath path = pathList.get(p);
            //still the paths should have the correct score.
            assertEquals(expectedScore, path.getScore());
            //we should have only one deletion.
            boolean foundDeletion = false;
            for (int o = 0; o < path.getOperations().size(); o++) {
                final OperationType type = path.getOperations().get(o).getType();
                switch (type) {
                    case DELETION:
                        assertFalse("We found more than one deletion in a path!", foundDeletion);
                        foundDeletion = true;
                        assertFalse("Two paths used the deletion at the same step!", variations[o]);
                        variations[o] = true;
                        break;
                    case REPLACEMENT:
                        break;
                    default:
                        fail("We found other operations than deletions and insertion unexpectedly!");
                }
            }
        }
    }
}
